==> haskell-quickcheck-assertions-0.3.0-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-IZmaMOYKmB4Jso7HdyjF9O
key: quickcheck-assertions-0.3.0-IZmaMOYKmB4Jso7HdyjF9O
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: a790f9dc2f50c54dd4ee358c6ab26cf1
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-IZmaMOYKmB4Jso7HdyjF9O
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-Juf5NXowsQ8B5sl0XoaaKN
key: quickcheck-assertions-0.3.0-Juf5NXowsQ8B5sl0XoaaKN
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: 337a7e0330ede774dbd42255b906539b
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-Juf5NXowsQ8B5sl0XoaaKN
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
